Class: Toys::Flag

Inherits:
Object
  • Object
show all
Defined in:
core-docs/toys/flag.rb

Overview

Representation of a formal set of flags that set a particular context key. The flags within a single Flag definition are synonyms.

Defined in the toys-core gem

Defined Under Namespace

Classes: DefaultCompletion, Resolution, Syntax

Constant Summary collapse

SET_HANDLER =

The set handler replaces the previous value.

Returns:

  • (Proc)
proc { |val| val }
PUSH_HANDLER =

The push handler pushes the given value using the << operator.

Returns:

  • (Proc)
proc { |val, prev| prev.nil? ? [val] : prev << val }
DEFAULT_HANDLER =

The default handler is the set handler, which replaces the previous value.

Returns:

  • (Proc)
SET_HANDLER

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#acceptorToys::Acceptor::Base (readonly)

Returns the effective acceptor.



356
357
358
# File 'core-docs/toys/flag.rb', line 356

def acceptor
  @acceptor
end

#defaultObject (readonly)

Returns the default value, which may be nil.

Returns:

  • (Object)


362
363
364
# File 'core-docs/toys/flag.rb', line 362

def default
  @default
end

#descToys::WrappableString

The short description string.

When reading, this is always returned as a WrappableString.

When setting, the description may be provided as any of the following:

  • A WrappableString.
  • A normal String, which will be transformed into a WrappableString using spaces as word delimiters.
  • An Array of String, which will be transformed into a WrappableString where each array element represents an individual word for wrapping.


379
380
381
# File 'core-docs/toys/flag.rb', line 379

def desc
  @desc
end

#display_nameString (readonly)

The display name of this flag.

Returns:

  • (String)


456
457
458
# File 'core-docs/toys/flag.rb', line 456

def display_name
  @display_name
end

#flag_completionProc, Toys::Completion::Base (readonly)

The proc that determines shell completions for the flag.

Returns:



410
411
412
# File 'core-docs/toys/flag.rb', line 410

def flag_completion
  @flag_completion
end

#flag_syntaxArray<Toys::Flag::Syntax> (readonly)

Returns an array of Flag::Syntax for the flags.

Returns:



350
351
352
# File 'core-docs/toys/flag.rb', line 350

def flag_syntax
  @flag_syntax
end

#flag_type:boolean, :value (readonly)

The type of flag.

Returns:

  • (:boolean)

    if the flag is a simple boolean switch

  • (:value)

    if the flag sets a value



424
425
426
# File 'core-docs/toys/flag.rb', line 424

def flag_type
  @flag_type
end

#groupToys::FlagGroup (readonly)

Returns the flag group containing this flag

Returns:



338
339
340
# File 'core-docs/toys/flag.rb', line 338

def group
  @group
end

#handlerProc (readonly)

The handler for setting/updating the value.

Returns:

  • (Proc)


404
405
406
# File 'core-docs/toys/flag.rb', line 404

def handler
  @handler
end

#keySymbol (readonly)

Returns the key.

Returns:

  • (Symbol)


344
345
346
# File 'core-docs/toys/flag.rb', line 344

def key
  @key
end

#long_descArray<Toys::WrappableString>

The long description strings.

When reading, this is returned as an Array of WrappableString representing the lines in the description.

When setting, the description must be provided as an Array where each element may be any of the following:

  • A WrappableString representing one line.
  • A normal String representing a line. This will be transformed into a WrappableString using spaces as word delimiters.
  • An Array of String representing a line. This will be transformed into a WrappableString where each array element represents an individual word for wrapping.

Returns:



398
399
400
# File 'core-docs/toys/flag.rb', line 398

def long_desc
  @long_desc
end

#sort_strString (readonly)

A string that can be used to sort this flag

Returns:

  • (String)


462
463
464
# File 'core-docs/toys/flag.rb', line 462

def sort_str
  @sort_str
end

#value_completionProc, Toys::Completion::Base (readonly)

The proc that determines shell completions for the value.

Returns:



416
417
418
# File 'core-docs/toys/flag.rb', line 416

def value_completion
  @value_completion
end

#value_delimString? (readonly)

The value delimiter, which may be "", " ", or "=".

Returns:

  • (String)

    The delimiter

  • (nil)

    if the flag type is not :value.



450
451
452
# File 'core-docs/toys/flag.rb', line 450

def value_delim
  @value_delim
end

#value_labelString? (readonly)

The string label for the value as it should display in help.

Returns:

  • (String)

    The label

  • (nil)

    if the flag type is not :value.



442
443
444
# File 'core-docs/toys/flag.rb', line 442

def value_label
  @value_label
end

#value_type:required, ... (readonly)

The type of value.

Returns:

  • (:required)

    if the flag type is :value and the value is required.

  • (:optional)

    if the flag type is :value and the value is optional.

  • (nil)

    if the flag type is not :value.



435
436
437
# File 'core-docs/toys/flag.rb', line 435

def value_type
  @value_type
end

Class Method Details

.create(key, flags = [], used_flags: nil, report_collisions: true, accept: nil, handler: nil, default: nil, complete_flags: nil, complete_values: nil, display_name: nil, desc: nil, long_desc: nil, group: nil) ⇒ Object

Create a flag definition.

Parameters:

  • key (String, Symbol)

    The key to use to retrieve the value from the execution context.

  • flags (Array<String>) (defaults to: [])

    The flags in OptionParser format. If empty, a flag will be inferred from the key.

  • accept (Object) (defaults to: nil)

    An acceptor that validates and/or converts the value. See Acceptor.create for recognized formats. Optional. If not specified, defaults to Acceptor::DEFAULT.

  • default (Object) (defaults to: nil)

    The default value. This is the value that will be set in the context if this flag is not provided on the command line. Defaults to nil.

  • handler (Proc, nil, :set, :push, :append) (defaults to: nil)

    An optional handler that customizes how a value is set or updated when the flag is parsed. A handler is a proc that takes up to three arguments: the given value, the previous value, and a hash containing all the data collected so far during argument parsing. The proc must return the new value for the flag. You may also specify a predefined named handler. The :set handler (the default) replaces the previous value (effectively -> (val) { val }). The :push handler expects the previous value to be an array and pushes the given value onto it; it should be combined with setting default: [] and is intended for "multi-valued" flags. :append is an alias for :push.

  • complete_flags (Object) (defaults to: nil)

    A specifier for shell tab completion for flag names associated with this flag. By default, a DefaultCompletion is used, which provides the flag's names as completion candidates. To customize completion, set this to a hash of options to pass to the constructor for DefaultCompletion, or pass any other spec recognized by Completion.create.

  • complete_values (Object) (defaults to: nil)

    A specifier for shell tab completion for flag values associated with this flag. Pass any spec recognized by Completion.create.

  • report_collisions (boolean) (defaults to: true)

    Raise an exception if a flag is requested that is already in use or marked as disabled. Default is true.

  • group (Toys::FlagGroup) (defaults to: nil)

    Group containing this flag.

  • desc (String, Array<String>, Toys::WrappableString) (defaults to: nil)

    Short description for the flag. See ToolDefinition#desc for a description of allowed formats. Defaults to the empty string.

  • long_desc (Array<String,Array<String>,Toys::WrappableString>) (defaults to: nil)

    Long description for the flag. See ToolDefinition#long_desc for a description of allowed formats. Defaults to the empty array.

  • display_name (String) (defaults to: nil)

    A display name for this flag, used in help text and error messages.

  • used_flags (Array<String>) (defaults to: nil)

    An array of flags already in use.



327
328
329
330
331
332
# File 'core-docs/toys/flag.rb', line 327

def self.create(key, flags = [],
                used_flags: nil, report_collisions: true, accept: nil, handler: nil,
                default: nil, complete_flags: nil, complete_values: nil, display_name: nil,
                desc: nil, long_desc: nil, group: nil)
  # Source available in the toys-core gem
end

Instance Method Details

#active?boolean

Whether this flag is active--that is, it has a nonempty flags list.

Returns:

  • (boolean)


514
515
516
# File 'core-docs/toys/flag.rb', line 514

def active?
  # Source available in the toys-core gem
end

#append_long_desc(long_desc) ⇒ self

Append long description strings.

You must pass an array of lines in the long description. See #long_desc for details on how each line may be represented.

Parameters:

Returns:

  • (self)


549
550
551
# File 'core-docs/toys/flag.rb', line 549

def append_long_desc(long_desc)
  # Source available in the toys-core gem
end

#canonical_syntax_stringsArray<String>

A list of canonical flag syntax strings.

Returns:

  • (Array<String>)


505
506
507
# File 'core-docs/toys/flag.rb', line 505

def canonical_syntax_strings
  # Source available in the toys-core gem
end

#effective_flagsArray<String>

The list of all effective flags used.

Returns:

  • (Array<String>)


484
485
486
# File 'core-docs/toys/flag.rb', line 484

def effective_flags
  # Source available in the toys-core gem
end

#long_flag_syntaxArray<Flag::Syntax>

An array of Flag::Syntax including only long (double-dash) flags.

Returns:



476
477
478
# File 'core-docs/toys/flag.rb', line 476

def long_flag_syntax
  # Source available in the toys-core gem
end

#resolve(str) ⇒ Toys::Flag::Resolution

Look up the flag by string. Returns an object that indicates whether the given string matched this flag, whether the match was unique, and other pertinent information.

Parameters:

  • str (String)

    Flag string to look up

Returns:



496
497
498
# File 'core-docs/toys/flag.rb', line 496

def resolve(str)
  # Source available in the toys-core gem
end

#short_flag_syntaxArray<Flag::Syntax>

An array of Flag::Syntax including only short (single dash) flags.

Returns:



468
469
470
# File 'core-docs/toys/flag.rb', line 468

def short_flag_syntax
  # Source available in the toys-core gem
end