Class: Toys::Flag::Resolution

Inherits:
Object
  • Object
show all
Defined in:
core-docs/toys/flag.rb

Overview

The result of looking up a flag by name.

Defined in the toys-core gem

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#stringString (readonly)

The flag string that was looked up



127
128
129
# File 'core-docs/toys/flag.rb', line 127

def string
  @string
end

Instance Method Details

#countInteger

The number of matches that were found.



141
142
143
# File 'core-docs/toys/flag.rb', line 141

def count
  # Source available in the toys-core gem
end

#found_exact?boolean

Whether an exact match of the string was found



133
134
135
# File 'core-docs/toys/flag.rb', line 133

def found_exact?
  # Source available in the toys-core gem
end

#found_multiple?boolean

Whether multiple matches were found (i.e. ambiguous input).



165
166
167
# File 'core-docs/toys/flag.rb', line 165

def found_multiple?
  # Source available in the toys-core gem
end

#found_unique?boolean

Whether a single unique match was found.



149
150
151
# File 'core-docs/toys/flag.rb', line 149

def found_unique?
  # Source available in the toys-core gem
end

#matching_flag_stringsArray<String>

Returns an array of the matching full flag strings.



200
201
202
# File 'core-docs/toys/flag.rb', line 200

def matching_flag_strings
  # Source available in the toys-core gem
end

#not_found?boolean

Whether no matches were found.



157
158
159
# File 'core-docs/toys/flag.rb', line 157

def not_found?
  # Source available in the toys-core gem
end

#unique_flagToys::Flag?

Return the unique Toys::Flag, or nil if not found or not unique.



174
175
176
# File 'core-docs/toys/flag.rb', line 174

def unique_flag
  # Source available in the toys-core gem
end

#unique_flag_negative?boolean?

Return whether the unique match was a hit on the negative (--no-*) case, or nil if not found or not unique.



192
193
194
# File 'core-docs/toys/flag.rb', line 192

def unique_flag_negative?
  # Source available in the toys-core gem
end

#unique_flag_syntaxToys::Flag::Syntax?

Return the unique Syntax, or nil if not found or not unique.



183
184
185
# File 'core-docs/toys/flag.rb', line 183

def unique_flag_syntax
  # Source available in the toys-core gem
end