Exception: Toys::NotRunnableError

Inherits:
StandardError
  • Object
show all
Defined in:
core-docs/toys/errors.rb

Overview

An exception indicating an attempt to run a tool that has no run method or otherwise cannot be run.

Defined in the toys-core gem