Class: Toys::PositionalArg
- Inherits:
-
Object
- Object
- Toys::PositionalArg
- Defined in:
- core-docs/toys/positional_arg.rb
Overview
Defined in the toys-core gem
Representation of a formal positional argument
Instance Attribute Summary collapse
-
#acceptor ⇒ Toys::Acceptor::Base
readonly
The effective acceptor.
-
#completion ⇒ Proc, Toys::Completion::Base
readonly
The proc that determines shell completions for the value.
-
#default ⇒ Object
readonly
The default value, which may be
nil. -
#desc ⇒ Toys::WrappableString
The short description string.
-
#display_name ⇒ String
readonly
The displayable name.
-
#key ⇒ Symbol
readonly
The key for this arg.
-
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
-
#type ⇒ :required, ...
readonly
Type of this argument.
Class Method Summary collapse
-
.create(key, type, accept: nil, default: nil, complete: nil, desc: nil, long_desc: nil, display_name: nil) ⇒ Toys::PositionalArg
Create a PositionalArg definition.
Instance Method Summary collapse
-
#append_long_desc(long_desc) ⇒ self
Append long description strings.
Instance Attribute Details
#acceptor ⇒ Toys::Acceptor::Base (readonly)
The effective acceptor.
57 58 59 |
# File 'core-docs/toys/positional_arg.rb', line 57 def acceptor @acceptor end |
#completion ⇒ Proc, Toys::Completion::Base (readonly)
The proc that determines shell completions for the value.
69 70 71 |
# File 'core-docs/toys/positional_arg.rb', line 69 def completion @completion end |
#default ⇒ Object (readonly)
The default value, which may be nil.
63 64 65 |
# File 'core-docs/toys/positional_arg.rb', line 63 def default @default end |
#desc ⇒ Toys::WrappableString
The short description string.
When reading, this is always returned as a WrappableString.
When setting, the description may be provided as any of the following:
- A WrappableString.
- A normal String, which will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String, which will be transformed into a WrappableString where each array element represents an individual word for wrapping.
86 87 88 |
# File 'core-docs/toys/positional_arg.rb', line 86 def desc @desc end |
#display_name ⇒ String (readonly)
The displayable name.
111 112 113 |
# File 'core-docs/toys/positional_arg.rb', line 111 def display_name @display_name end |
#key ⇒ Symbol (readonly)
The key for this arg.
45 46 47 |
# File 'core-docs/toys/positional_arg.rb', line 45 def key @key end |
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
When reading, this is returned as an Array of WrappableString representing the lines in the description.
When setting, the description must be provided as an Array where each element may be any of the following:
- A WrappableString representing one line.
- A normal String representing a line. This will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String representing a line. This will be transformed into a WrappableString where each array element represents an individual word for wrapping.
105 106 107 |
# File 'core-docs/toys/positional_arg.rb', line 105 def long_desc @long_desc end |
#type ⇒ :required, ... (readonly)
Type of this argument.
51 52 53 |
# File 'core-docs/toys/positional_arg.rb', line 51 def type @type end |
Class Method Details
.create(key, type, accept: nil, default: nil, complete: nil, desc: nil, long_desc: nil, display_name: nil) ⇒ Toys::PositionalArg
Create a PositionalArg definition.
35 36 37 38 39 |
# File 'core-docs/toys/positional_arg.rb', line 35 def self.create(key, type, accept: nil, default: nil, complete: nil, desc: nil, long_desc: nil, display_name: nil) # Source available in the toys-core gem end |
Instance Method Details
#append_long_desc(long_desc) ⇒ self
Append long description strings.
You must pass an array of lines in the long description. See #long_desc for details on how each line may be represented.
144 145 146 |
# File 'core-docs/toys/positional_arg.rb', line 144 def append_long_desc(long_desc) # Source available in the toys-core gem end |