Class: Toys::SourceSpec::Block

Inherits:
Base
  • Object
show all
Defined in:
core-docs/toys/source_spec.rb

Overview

A spec for a source given as a block of DSL code.

Defined in the toys-core gem

Instance Attribute Summary collapse

Attributes inherited from Base

#context_directory, #source_name

Method Summary

Methods inherited from Base

#==, #hash

Instance Attribute Details

#block ⇒ Proc (readonly)

The source block, to be executed in the context of the tool DSL DSL::Tool.

Returns:

  • (Proc)


335
336
337
# File 'core-docs/toys/source_spec.rb', line 335

def block
  @block
end