Class: Toys::SourceSpec::Git

Inherits:
Base
  • Object
show all
Defined in:
core-docs/toys/source_spec.rb

Overview

A spec for a source located in a git repository.

Defined in the toys-core gem

Instance Attribute Summary collapse

Attributes inherited from Base

#context_directory, #source_name

Method Summary

Methods inherited from Base

#==, #hash

Instance Attribute Details

#commit ⇒ String? (readonly)

The git ref, or nil to inherit it from the source doing the loading or fall back to "HEAD".

Returns:

  • (String, nil)


250
251
252
# File 'core-docs/toys/source_spec.rb', line 250

def commit
  @commit
end

#path ⇒ String? (readonly)

The path within the repo, or nil for the root of the repo.

Returns:

  • (String, nil)


242
243
244
# File 'core-docs/toys/source_spec.rb', line 242

def path
  @path
end

#remote ⇒ String? (readonly)

The git repo URL, or nil to inherit it from the source doing the loading.

Returns:

  • (String, nil)


235
236
237
# File 'core-docs/toys/source_spec.rb', line 235

def remote
  @remote
end

#update ⇒ boolean, Integer (readonly)

Whether, and when, to force-fetch from the remote.

Returns:

  • (boolean, Integer)


257
258
259
# File 'core-docs/toys/source_spec.rb', line 257

def update
  @update
end