Class: Toys::SourceSpec::Path

Inherits:
Base
  • Object
show all
Defined in:
core-docs/toys/source_spec.rb

Overview

A spec for a source located by file system path.

Defined in the toys-core gem

Instance Attribute Summary collapse

Attributes inherited from Base

#context_directory, #source_name

Method Summary

Methods inherited from Base

#==, #hash

Instance Attribute Details

#path ⇒ String (readonly)

The file system path. If #relative_paths is non-nil, this is the root directory those paths are relative to.

Returns:

  • (String)


210
211
212
# File 'core-docs/toys/source_spec.rb', line 210

def path
  @path
end

#relative_paths ⇒ Array<String>? (readonly)

The paths to load, relative to #path, or nil to load #path itself. The empty array means load nothing from the root.

Returns:

  • (Array<String>, nil)


218
219
220
# File 'core-docs/toys/source_spec.rb', line 218

def relative_paths
  @relative_paths
end