Exception: Toys::Utils::GitCache::Error

Inherits:
StandardError
  • Object
show all
Defined in:
core-docs/toys/utils/git_cache.rb

Overview

Defined in the toys-core gem

Toys::Utils::GitCache encountered a failure

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(message, result) ⇒ Error

Create a Toys::Utils::GitCache::Error.

Parameters:

  • message (String)

    The error message

  • result (::Toys::Utils::Exec::Result)

    The result of a git command execution, or nil if this error was not due to a git command error.



165
166
167
# File 'core-docs/toys/utils/git_cache.rb', line 165

def initialize(message, result)
  # Source available in the toys-core gem
end

Instance Attribute Details

#exec_result::Toys::Utils::Exec::Result (readonly)

Returns The result of a git command execution, or nil if this error was not due to a git command error.

Returns:



174
175
176
# File 'core-docs/toys/utils/git_cache.rb', line 174

def exec_result
  @exec_result
end