Class: Toys::Completion::Candidate
- Inherits:
-
Object
- Object
- Toys::Completion::Candidate
- Includes:
- Comparable
- Defined in:
- core-docs/toys/completion.rb
Overview
Defined in the toys-core gem
A candidate for completing a string fragment.
A candidate includes a string representing the potential completed word, as well as a flag indicating whether it is a partial completion (i.e. a prefix that could still be added to) versus a final word. Generally, tab completion systems should add a trailing space after a final completion but not after a partial completion.
Instance Attribute Summary collapse
-
#string ⇒ String
(also: #to_s)
readonly
Get the candidate string.
Class Method Summary collapse
-
.new_multi(array, partial: false) ⇒ Array<Toys::Completion::Candidate>
Create an array of candidates given an array of strings.
Instance Method Summary collapse
-
#final? ⇒ boolean
Determine whether the candidate is a final completion.
-
#initialize(string, partial: false) ⇒ Candidate
constructor
Create a new candidate.
-
#partial? ⇒ boolean
Determine whether the candidate is partial completion.
Constructor Details
#initialize(string, partial: false) ⇒ Candidate
Create a new candidate
136 137 138 |
# File 'core-docs/toys/completion.rb', line 136 def initialize(string, partial: false) # Source available in the toys-core gem end |
Instance Attribute Details
#string ⇒ String (readonly) Also known as: to_s
Get the candidate string.
144 145 146 |
# File 'core-docs/toys/completion.rb', line 144 def string @string end |
Class Method Details
.new_multi(array, partial: false) ⇒ Array<Toys::Completion::Candidate>
Create an array of candidates given an array of strings.
169 170 171 |
# File 'core-docs/toys/completion.rb', line 169 def self.new_multi(array, partial: false) # Source available in the toys-core gem end |
Instance Method Details
#final? ⇒ boolean
Determine whether the candidate is a final completion.
159 160 161 |
# File 'core-docs/toys/completion.rb', line 159 def final? # Source available in the toys-core gem end |
#partial? ⇒ boolean
Determine whether the candidate is partial completion.
151 152 153 |
# File 'core-docs/toys/completion.rb', line 151 def partial? # Source available in the toys-core gem end |