Class: Toys::Flag
- Inherits:
-
Object
- Object
- Toys::Flag
- Defined in:
- core-docs/toys/flag.rb
Overview
Representation of a formal set of flags that set a particular context key. The flags within a single Flag definition are synonyms.
Defined in the toys-core gem
Defined Under Namespace
Classes: DefaultCompletion, Resolution, Syntax
Constant Summary collapse
- SET_HANDLER =
The set handler replaces the previous value.
proc { |val| val }
- PUSH_HANDLER =
The push handler pushes the given value using the
<<operator. proc { |val, prev| prev.nil? ? [val] : prev << val }
- DEFAULT_HANDLER =
The default handler is the set handler, which replaces the previous value.
SET_HANDLER
Instance Attribute Summary collapse
-
#acceptor ⇒ Toys::Acceptor::Base
readonly
Returns the effective acceptor.
-
#default ⇒ Object
readonly
Returns the default value, which may be
nil. -
#desc ⇒ Toys::WrappableString
The short description string.
-
#display_name ⇒ String
readonly
The display name of this flag.
-
#flag_completion ⇒ Proc, Toys::Completion::Base
readonly
The proc that determines shell completions for the flag.
-
#flag_syntax ⇒ Array<Toys::Flag::Syntax>
readonly
Returns an array of Flag::Syntax for the flags.
-
#flag_type ⇒ :boolean, :value
readonly
The type of flag.
-
#group ⇒ Toys::FlagGroup
readonly
Returns the flag group containing this flag.
-
#handler ⇒ Proc
readonly
The handler for setting/updating the value.
-
#key ⇒ Symbol
readonly
Returns the key.
-
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
-
#sort_str ⇒ String
readonly
A string that can be used to sort this flag.
-
#value_completion ⇒ Proc, Toys::Completion::Base
readonly
The proc that determines shell completions for the value.
-
#value_delim ⇒ String?
readonly
The value delimiter, which may be
""," ", or"=". -
#value_label ⇒ String?
readonly
The string label for the value as it should display in help.
-
#value_type ⇒ :required, ...
readonly
The type of value.
Class Method Summary collapse
-
.create(key, flags = [], used_flags: nil, report_collisions: true, accept: nil, handler: nil, default: nil, complete_flags: nil, complete_values: nil, display_name: nil, desc: nil, long_desc: nil, group: nil) ⇒ Object
Create a flag definition.
Instance Method Summary collapse
-
#active? ⇒ boolean
Whether this flag is active--that is, it has a nonempty flags list.
-
#append_long_desc(long_desc) ⇒ self
Append long description strings.
-
#canonical_syntax_strings ⇒ Array<String>
A list of canonical flag syntax strings.
-
#effective_flags ⇒ Array<String>
The list of all effective flags used.
-
#long_flag_syntax ⇒ Array<Flag::Syntax>
An array of Flag::Syntax including only long (double-dash) flags.
-
#resolve(str) ⇒ Toys::Flag::Resolution
Look up the flag by string.
-
#short_flag_syntax ⇒ Array<Flag::Syntax>
An array of Flag::Syntax including only short (single dash) flags.
Instance Attribute Details
#acceptor ⇒ Toys::Acceptor::Base (readonly)
Returns the effective acceptor.
356 357 358 |
# File 'core-docs/toys/flag.rb', line 356 def acceptor @acceptor end |
#default ⇒ Object (readonly)
Returns the default value, which may be nil.
362 363 364 |
# File 'core-docs/toys/flag.rb', line 362 def default @default end |
#desc ⇒ Toys::WrappableString
The short description string.
When reading, this is always returned as a WrappableString.
When setting, the description may be provided as any of the following:
- A WrappableString.
- A normal String, which will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String, which will be transformed into a WrappableString where each array element represents an individual word for wrapping.
379 380 381 |
# File 'core-docs/toys/flag.rb', line 379 def desc @desc end |
#display_name ⇒ String (readonly)
The display name of this flag.
456 457 458 |
# File 'core-docs/toys/flag.rb', line 456 def display_name @display_name end |
#flag_completion ⇒ Proc, Toys::Completion::Base (readonly)
The proc that determines shell completions for the flag.
410 411 412 |
# File 'core-docs/toys/flag.rb', line 410 def flag_completion @flag_completion end |
#flag_syntax ⇒ Array<Toys::Flag::Syntax> (readonly)
Returns an array of Flag::Syntax for the flags.
350 351 352 |
# File 'core-docs/toys/flag.rb', line 350 def flag_syntax @flag_syntax end |
#flag_type ⇒ :boolean, :value (readonly)
The type of flag.
424 425 426 |
# File 'core-docs/toys/flag.rb', line 424 def flag_type @flag_type end |
#group ⇒ Toys::FlagGroup (readonly)
Returns the flag group containing this flag
338 339 340 |
# File 'core-docs/toys/flag.rb', line 338 def group @group end |
#handler ⇒ Proc (readonly)
The handler for setting/updating the value.
404 405 406 |
# File 'core-docs/toys/flag.rb', line 404 def handler @handler end |
#key ⇒ Symbol (readonly)
Returns the key.
344 345 346 |
# File 'core-docs/toys/flag.rb', line 344 def key @key end |
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
When reading, this is returned as an Array of WrappableString representing the lines in the description.
When setting, the description must be provided as an Array where each element may be any of the following:
- A WrappableString representing one line.
- A normal String representing a line. This will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String representing a line. This will be transformed into a WrappableString where each array element represents an individual word for wrapping.
398 399 400 |
# File 'core-docs/toys/flag.rb', line 398 def long_desc @long_desc end |
#sort_str ⇒ String (readonly)
A string that can be used to sort this flag
462 463 464 |
# File 'core-docs/toys/flag.rb', line 462 def sort_str @sort_str end |
#value_completion ⇒ Proc, Toys::Completion::Base (readonly)
The proc that determines shell completions for the value.
416 417 418 |
# File 'core-docs/toys/flag.rb', line 416 def value_completion @value_completion end |
#value_delim ⇒ String? (readonly)
The value delimiter, which may be "", " ", or "=".
450 451 452 |
# File 'core-docs/toys/flag.rb', line 450 def value_delim @value_delim end |
#value_label ⇒ String? (readonly)
The string label for the value as it should display in help.
442 443 444 |
# File 'core-docs/toys/flag.rb', line 442 def value_label @value_label end |
#value_type ⇒ :required, ... (readonly)
The type of value.
435 436 437 |
# File 'core-docs/toys/flag.rb', line 435 def value_type @value_type end |
Class Method Details
.create(key, flags = [], used_flags: nil, report_collisions: true, accept: nil, handler: nil, default: nil, complete_flags: nil, complete_values: nil, display_name: nil, desc: nil, long_desc: nil, group: nil) ⇒ Object
Create a flag definition.
327 328 329 330 331 332 |
# File 'core-docs/toys/flag.rb', line 327 def self.create(key, flags = [], used_flags: nil, report_collisions: true, accept: nil, handler: nil, default: nil, complete_flags: nil, complete_values: nil, display_name: nil, desc: nil, long_desc: nil, group: nil) # Source available in the toys-core gem end |
Instance Method Details
#active? ⇒ boolean
Whether this flag is active--that is, it has a nonempty flags list.
514 515 516 |
# File 'core-docs/toys/flag.rb', line 514 def active? # Source available in the toys-core gem end |
#append_long_desc(long_desc) ⇒ self
Append long description strings.
You must pass an array of lines in the long description. See #long_desc for details on how each line may be represented.
549 550 551 |
# File 'core-docs/toys/flag.rb', line 549 def append_long_desc(long_desc) # Source available in the toys-core gem end |
#canonical_syntax_strings ⇒ Array<String>
A list of canonical flag syntax strings.
505 506 507 |
# File 'core-docs/toys/flag.rb', line 505 def canonical_syntax_strings # Source available in the toys-core gem end |
#effective_flags ⇒ Array<String>
The list of all effective flags used.
484 485 486 |
# File 'core-docs/toys/flag.rb', line 484 def effective_flags # Source available in the toys-core gem end |
#long_flag_syntax ⇒ Array<Flag::Syntax>
An array of Flag::Syntax including only long (double-dash) flags.
476 477 478 |
# File 'core-docs/toys/flag.rb', line 476 def long_flag_syntax # Source available in the toys-core gem end |
#resolve(str) ⇒ Toys::Flag::Resolution
Look up the flag by string. Returns an object that indicates whether the given string matched this flag, whether the match was unique, and other pertinent information.
496 497 498 |
# File 'core-docs/toys/flag.rb', line 496 def resolve(str) # Source available in the toys-core gem end |
#short_flag_syntax ⇒ Array<Flag::Syntax>
An array of Flag::Syntax including only short (single dash) flags.
468 469 470 |
# File 'core-docs/toys/flag.rb', line 468 def short_flag_syntax # Source available in the toys-core gem end |