Class: Toys::FlagGroup::Base
- Inherits:
-
Object
- Object
- Toys::FlagGroup::Base
- Defined in:
- core-docs/toys/flag_group.rb
Overview
Defined in the toys-core gem
The base class of a FlagGroup, implementing everything except validation.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#desc ⇒ Toys::WrappableString
The short description string.
-
#flags ⇒ Array<Toys::Flag>
readonly
An array of flags that are in this group.
-
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
-
#name ⇒ String, ...
readonly
The symbolic name for this group.
Instance Method Summary collapse
-
#append_long_desc(long_desc) ⇒ self
Append long description strings.
-
#empty? ⇒ boolean
Returns true if this group is empty.
-
#summary ⇒ String
Returns a string summarizing this group.
Instance Attribute Details
#desc ⇒ Toys::WrappableString
The short description string.
When reading, this is always returned as a WrappableString.
When setting, the description may be provided as any of the following:
- A WrappableString.
- A normal String, which will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String, which will be transformed into a WrappableString where each array element represents an individual word for wrapping.
61 62 63 |
# File 'core-docs/toys/flag_group.rb', line 61 def desc @desc end |
#flags ⇒ Array<Toys::Flag> (readonly)
An array of flags that are in this group. Do not modify the returned array.
87 88 89 |
# File 'core-docs/toys/flag_group.rb', line 87 def flags @flags end |
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
When reading, this is returned as an Array of WrappableString representing the lines in the description.
When setting, the description must be provided as an Array where each element may be any of the following:
- A WrappableString representing one line.
- A normal String representing a line. This will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String representing a line. This will be transformed into a WrappableString where each array element represents an individual word for wrapping.
80 81 82 |
# File 'core-docs/toys/flag_group.rb', line 80 def long_desc @long_desc end |
#name ⇒ String, ... (readonly)
The symbolic name for this group
44 45 46 |
# File 'core-docs/toys/flag_group.rb', line 44 def name @name end |
Instance Method Details
#append_long_desc(long_desc) ⇒ self
Append long description strings.
You must pass an array of lines in the long description. See #long_desc for details on how each line may be represented.
137 138 139 |
# File 'core-docs/toys/flag_group.rb', line 137 def append_long_desc(long_desc) # Source available in the toys-core gem end |
#empty? ⇒ boolean
Returns true if this group is empty
93 94 95 |
# File 'core-docs/toys/flag_group.rb', line 93 def empty? # Source available in the toys-core gem end |
#summary ⇒ String
Returns a string summarizing this group. This is generally either the short description or a representation of all the flags included.
102 103 104 |
# File 'core-docs/toys/flag_group.rb', line 102 def summary # Source available in the toys-core gem end |