Class: Toys::Middleware::Spec

Inherits:
Object
  • Object
show all
Defined in:
core-docs/toys/middleware.rb

Overview

Defined in the toys-core gem

A middleware specification, including the middleware class and the arguments to pass to the constructor.

Use spec to create a middleware spec.

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#argsArray? (readonly)

Returns:

  • (Array)

    the positional arguments to be passed to a middleware class constructor, or the empty array if there are no positional arguments

  • (nil)

    if this spec wraps a middleware object



191
192
193
# File 'core-docs/toys/middleware.rb', line 191

def args
  @args
end

#blockProc? (readonly)

Returns:

  • (Proc)

    if there is a block argument to be passed to a middleware class constructor

  • (nil)

    if there is no block argument, or this spec wraps a middleware object



206
207
208
# File 'core-docs/toys/middleware.rb', line 206

def block
  @block
end

#kwargsHash? (readonly)

Returns:

  • (Hash)

    the keyword arguments to be passed to a middleware class constructor, or the empty hash if there are no keyword arguments

  • (nil)

    if this spec wraps a middleware object



198
199
200
# File 'core-docs/toys/middleware.rb', line 198

def kwargs
  @kwargs
end

#nameString, ... (readonly)

Returns:

  • (String, Symbol)

    if this spec represents a middleware name

  • (Class)

    if this spec represents a middleware class

  • (nil)

    if this spec wraps a middleware object



183
184
185
# File 'core-docs/toys/middleware.rb', line 183

def name
  @name
end

#objectToys::Middleware? (readonly)

Returns:

  • (Toys::Middleware)

    if this spec wraps a middleware object

  • (nil)

    if this spec represents a class to instantiate



176
177
178
# File 'core-docs/toys/middleware.rb', line 176

def object
  @object
end

Instance Method Details

#==(other) ⇒ boolean Also known as: eql?

Equality check

Parameters:

  • other (Object)

Returns:

  • (boolean)


214
215
216
# File 'core-docs/toys/middleware.rb', line 214

def ==(other)
  # Source available in the toys-core gem
end

#build(lookup) ⇒ Toys::Middleware

Builds a middleware for this spec, given a ModuleLookup for middleware.

If this spec wraps an existing middleware object, returns that object. Otherwise, constructs a middleware object from the spec.

Parameters:

Returns:



168
169
170
# File 'core-docs/toys/middleware.rb', line 168

def build(lookup)
  # Source available in the toys-core gem
end

#hashInteger

Return the hash code

Returns:

  • (Integer)


224
225
226
# File 'core-docs/toys/middleware.rb', line 224

def hash
  # Source available in the toys-core gem
end