Class: Toys::SourceInfo::Origin::Git
- Defined in:
- core-docs/toys/source_info/origin.rb
Overview
The origin of a source read from a git repository.
Defined in the toys-core gem
Instance Attribute Summary collapse
-
#commit ⇒ String
readonly
The git commit that the content was read at.
-
#path ⇒ String
readonly
The path within the repository that was read.
-
#remote ⇒ String
readonly
The git remote that the content was fetched from.
Instance Attribute Details
#commit ⇒ String (readonly)
The git commit that the content was read at. This is the ref that was requested, which could be a SHA, a tag, or a branch name.
71 72 73 |
# File 'core-docs/toys/source_info/origin.rb', line 71 def commit @commit end |
#path ⇒ String (readonly)
The path within the repository that was read. This is the path of the resolved source itself, and does not descend with child sources. It could be the empty string, meaning the root of the repository.
80 81 82 |
# File 'core-docs/toys/source_info/origin.rb', line 80 def path @path end |
#remote ⇒ String (readonly)
The git remote that the content was fetched from.
63 64 65 |
# File 'core-docs/toys/source_info/origin.rb', line 63 def remote @remote end |