Class: Toys::SourceSpec::Block
- Defined in:
- core-docs/toys/source_spec.rb
Overview
A spec for a source given as a block of DSL code.
Defined in the toys-core gem
Instance Attribute Summary collapse
-
#block ⇒ Proc
readonly
The source block, to be executed in the context of the tool DSL DSL::Tool.
Attributes inherited from Base
#context_directory, #source_name
Method Summary
Methods inherited from Base
Instance Attribute Details
#block ⇒ Proc (readonly)
The source block, to be executed in the context of the tool DSL DSL::Tool.
335 336 337 |
# File 'core-docs/toys/source_spec.rb', line 335 def block @block end |