Class: Toys::SourceSpec::Path
- Defined in:
- core-docs/toys/source_spec.rb
Overview
A spec for a source located by file system path.
Defined in the toys-core gem
Instance Attribute Summary collapse
-
#path ⇒ String
readonly
The file system path.
- #relative_paths ⇒ Array<String>? readonly
Attributes inherited from Base
#context_directory, #source_name
Method Summary
Methods inherited from Base
Instance Attribute Details
#path ⇒ String (readonly)
The file system path. If #relative_paths is non-nil, this is the root directory those paths are relative to.
210 211 212 |
# File 'core-docs/toys/source_spec.rb', line 210 def path @path end |