Module: Toys::StandardMixins::XDG
- Includes:
- Mixin
- Defined in:
- core-docs/toys/standard_mixins/xdg.rb
Overview
A mixin that provides tools for working with the XDG Base Directory Specification.
This mixin provides an instance of Utils::XDG, which includes utility methods that locate base directories and search paths for application state, configuration, caches, and other data, according to the XDG Base Directory Spec version 0.8.
Defined in the toys-core gem
Constant Summary collapse
- KEY =
Context key for the XDG object.
::Toys::UniqueKey.new("Toys::StandardMixins::XDG::KEY")
Instance Method Summary collapse
-
#xdg ⇒ Toys::Utils::XDG
Access XDG utility methods.
Methods included from Mixin
Instance Method Details
#xdg ⇒ Toys::Utils::XDG
Access XDG utility methods.
39 40 41 |
# File 'core-docs/toys/standard_mixins/xdg.rb', line 39 def xdg # Source available in the toys-core gem end |