Class: Toys::ToolDefinition
- Inherits:
-
Object
- Object
- Toys::ToolDefinition
- Defined in:
- core-docs/toys/tool_definition.rb
Overview
Defined in the toys-core gem
A ToolDefinition describes a single command that can be invoked using Toys. It has a name, a series of one or more words that you use to identify the tool on the command line. It also has a set of formal flags and command line arguments supported, and a block that gets run when the tool is executed.
Defined Under Namespace
Classes: DefaultCompletion
Instance Attribute Summary collapse
-
#built_middleware ⇒ Array<Toys::Middleware>
readonly
The stack of built middleware specs for this tool.
-
#completion ⇒ Toys::Completion::Base, Proc
The completion strategy for this tool.
-
#custom_context_directory ⇒ String?
The custom context directory set for this tool.
-
#default_data ⇒ Hash
readonly
The default context data set by arguments.
-
#delegate_target ⇒ Array<String>?
readonly
The full name of the delegate target, if any.
-
#desc ⇒ Toys::WrappableString
The short description string.
-
#flag_groups ⇒ Array<Toys::FlagGroup>
readonly
A list of all defined flag groups, in order.
-
#flags ⇒ Array<Toys::Flag>
readonly
A list of all defined flags.
-
#full_name ⇒ Array<String>
readonly
The name of the tool as an array of strings.
-
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
-
#optional_args ⇒ Array<Toys::PositionalArg>
readonly
A list of all defined optional positional arguments.
-
#priority ⇒ Integer
readonly
The priority of this tool definition.
-
#remaining_arg ⇒ Toys::PositionalArg?
readonly
The remaining arguments specification.
-
#required_args ⇒ Array<Toys::PositionalArg>
readonly
A list of all defined required positional arguments.
-
#run_handler ⇒ Proc, ...
The run handler.
-
#source_info ⇒ Toys::SourceInfo?
readonly
Info on the source of this tool.
-
#source_root ⇒ Toys::SourceInfo?
readonly
The root source info defining this tool, or nil if there is no source.
-
#subtool_middleware_stack ⇒ Array<Toys::Middleware::Spec>
readonly
The stack of middleware specs used for subtools.
-
#tool_class ⇒ Class
readonly
The tool class.
-
#usage_error_handler ⇒ Proc, ...
The usage error handler.
-
#used_flags ⇒ Array<String>
readonly
A list of flags that have been used in the flag definitions.
Instance Method Summary collapse
-
#add_acceptor(name, acceptor = nil, type_desc: nil, &block) ⇒ self
Add a named acceptor to the tool.
-
#add_completion(name, completion = nil, **options, &block) ⇒ self
Add a named completion proc to this tool.
-
#add_flag(key, flags = [], accept: nil, default: nil, handler: nil, complete_flags: nil, complete_values: nil, report_collisions: true, group: nil, desc: nil, long_desc: nil, display_name: nil) ⇒ self
Add a flag to the current tool.
-
#add_flag_group(type: :optional, desc: nil, long_desc: nil, name: nil, report_collisions: true, prepend: false) ⇒ self
Add a flag group to the group list.
-
#add_initializer(proc, *args, **kwargs) ⇒ self
Add an initializer.
-
#add_mixin(name, mixin_module = nil, &block) ⇒ self
Add a named mixin module to this tool.
-
#add_optional_arg(key, default: nil, accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) ⇒ self
Add an optional positional argument to the current tool.
-
#add_required_arg(key, accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) ⇒ self
Add a required positional argument to the current tool.
-
#add_template(name, template_class = nil, &block) ⇒ self
Add a named template class to this tool.
-
#append_long_desc(long_desc) ⇒ self
Append long description strings.
-
#argument_parsing_disabled? ⇒ true, false
Returns true if this tool has disabled argument parsing.
-
#context_directory ⇒ String?
Return the effective context directory.
-
#definition_finished? ⇒ true, false
Returns true if this tool's definition has been finished and is locked.
-
#delegate_to(target) ⇒ self
Causes this tool to delegate to another tool.
-
#disable_argument_parsing ⇒ self
Disable argument parsing for this tool.
-
#disable_flag(*flags) ⇒ self
Mark one or more flags as disabled, preventing their use by any subsequent flag definition.
-
#display_name ⇒ String
A displayable name of this tool, generally the full name delimited by spaces.
-
#enforce_flags_before_args(state = true) ⇒ self
Enforce that flags must come before args for this tool.
-
#exact_flag_match_required? ⇒ true, false
Returns true if this tool requires exact flag matches.
-
#flags_before_args_enforced? ⇒ true, false
Returns true if this tool enforces flags before args.
-
#handles_interrupts? ⇒ true, false
Returns true if this tool handles interrupts.
-
#handles_signal?(signal) ⇒ true, false
Returns true if this tool handles the given signal.
-
#handles_usage_errors? ⇒ true, false
Returns true if this tool handles usage errors.
-
#include_mixin(mod, *args, **kwargs) ⇒ self
Include the given mixin in the tool class.
-
#includes_arguments? ⇒ true, false
Returns true if at least one flag or positional argument is defined for this tool.
-
#includes_definition? ⇒ true, false
Returns true if this tool has any definition information.
-
#includes_description? ⇒ true, false
Returns true if there is a specific description set for this tool.
-
#includes_modules? ⇒ true, false
Returns true if this tool has at least one included module.
-
#inheritable_helper_methods=(val) ⇒ Object
Set whether helper methods defined in this tool are inherited by subtools.
-
#inheritable_helper_methods? ⇒ true, false
Returns true if helper methods defined in this class are inherited by subtools.
-
#interrupt_handler ⇒ Proc, ...
Return the interrupt handler.
-
#interrupt_handler=(handler) ⇒ Object
Set the interrupt handler.
-
#lock_source(source) ⇒ self
Sets the path to the file that defines this tool.
-
#lookup_acceptor(name) ⇒ Toys::Acceptor::Base?
Get the named acceptor from this tool or its ancestors.
-
#lookup_completion(name) ⇒ Toys::Completion::Base, ...
Get the named completion from this tool or its ancestors.
-
#lookup_mixin(name) ⇒ Module?
Get the named mixin from this tool or its ancestors.
-
#lookup_template(name) ⇒ Class?
Get the named template from this tool or its ancestors.
-
#positional_args ⇒ Array<Toys::PositionalArg>
All arg definitions in order: required, optional, remaining.
-
#require_exact_flag_match(state = true) ⇒ self
Require that flags must match exactly.
-
#resolve_flag(str) ⇒ Toys::Flag::Resolution
Resolve the given flag given the flag string.
-
#root? ⇒ true, false
Returns true if this tool is a root tool.
-
#runnable? ⇒ true, false
Returns true if this tool is marked as runnable.
-
#set_remaining_args(key, default: [], accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) ⇒ self
Specify what should be done with unmatched positional arguments.
-
#set_signal_handler(signal, handler) ⇒ Object
Set the handler for the given signal.
-
#signal_handler(signal) ⇒ Proc, ...
Return the signal handler for the given signal.
-
#simple_name ⇒ String
The local name of this tool, i.e.
Instance Attribute Details
#built_middleware ⇒ Array<Toys::Middleware> (readonly)
The stack of built middleware specs for this tool.
245 246 247 |
# File 'core-docs/toys/tool_definition.rb', line 245 def built_middleware @built_middleware end |
#completion ⇒ Toys::Completion::Base, Proc
The completion strategy for this tool.
When reading, this may return an instance of one of the subclasses of Completion::Base, or a Proc that duck-types it. Generally, this defaults to a DefaultCompletion, providing a standard algorithm that finds appropriate completions from flags, positional arguments, and subtools.
When setting, you may pass any of the following:
-
nilor:defaultwhich sets the value to a default instance. - A Hash of options to pass to the DefaultCompletion constructor.
- Any other form recognized by Completion.create.
280 281 282 |
# File 'core-docs/toys/tool_definition.rb', line 280 def completion @completion end |
#custom_context_directory ⇒ String?
The custom context directory set for this tool.
261 262 263 |
# File 'core-docs/toys/tool_definition.rb', line 261 def custom_context_directory @custom_context_directory end |
#default_data ⇒ Hash (readonly)
The default context data set by arguments.
229 230 231 |
# File 'core-docs/toys/tool_definition.rb', line 229 def default_data @default_data end |
#delegate_target ⇒ Array<String>? (readonly)
The full name of the delegate target, if any.
320 321 322 |
# File 'core-docs/toys/tool_definition.rb', line 320 def delegate_target @delegate_target end |
#desc ⇒ Toys::WrappableString
The short description string.
When reading, this is always returned as a WrappableString.
When setting, the description may be provided as any of the following:
- A WrappableString.
- A normal String, which will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String, which will be transformed into a WrappableString where each array element represents an individual word for wrapping.
160 161 162 |
# File 'core-docs/toys/tool_definition.rb', line 160 def desc @desc end |
#flag_groups ⇒ Array<Toys::FlagGroup> (readonly)
A list of all defined flag groups, in order.
186 187 188 |
# File 'core-docs/toys/tool_definition.rb', line 186 def flag_groups @flag_groups end |
#flags ⇒ Array<Toys::Flag> (readonly)
A list of all defined flags.
193 194 195 |
# File 'core-docs/toys/tool_definition.rb', line 193 def flags @flags end |
#full_name ⇒ Array<String> (readonly)
The name of the tool as an array of strings. This array may not be modified.
122 123 124 |
# File 'core-docs/toys/tool_definition.rb', line 122 def full_name @full_name end |
#long_desc ⇒ Array<Toys::WrappableString>
The long description strings.
When reading, this is returned as an Array of WrappableString representing the lines in the description.
When setting, the description must be provided as an Array where each element may be any of the following:
- A WrappableString representing one line.
- A normal String representing a line. This will be transformed into a WrappableString using spaces as word delimiters.
- An Array of String representing a line. This will be transformed into a WrappableString where each array element represents an individual word for wrapping.
179 180 181 |
# File 'core-docs/toys/tool_definition.rb', line 179 def long_desc @long_desc end |
#optional_args ⇒ Array<Toys::PositionalArg> (readonly)
A list of all defined optional positional arguments.
207 208 209 |
# File 'core-docs/toys/tool_definition.rb', line 207 def optional_args @optional_args end |
#priority ⇒ Integer (readonly)
The priority of this tool definition.
129 130 131 |
# File 'core-docs/toys/tool_definition.rb', line 129 def priority @priority end |
#remaining_arg ⇒ Toys::PositionalArg? (readonly)
The remaining arguments specification.
215 216 217 |
# File 'core-docs/toys/tool_definition.rb', line 215 def remaining_arg @remaining_arg end |
#required_args ⇒ Array<Toys::PositionalArg> (readonly)
A list of all defined required positional arguments.
200 201 202 |
# File 'core-docs/toys/tool_definition.rb', line 200 def required_args @required_args end |
#run_handler ⇒ Proc, ...
The run handler.
This handler is called to run the tool. Normally it is a method name,
represented by a symbol. (The default is :run.) It can be set to a
different method name, or to a proc that will be called with self set
to the tool context. Either way, it takes no arguments. The run handler
can also be explicitly set to nil indicating a non-runnable tool;
however, typically a tool is made non-runnable simply by leaving the run
handler set to :run and not defining the method.
297 298 299 |
# File 'core-docs/toys/tool_definition.rb', line 297 def run_handler @run_handler end |
#source_info ⇒ Toys::SourceInfo? (readonly)
Info on the source of this tool.
253 254 255 |
# File 'core-docs/toys/tool_definition.rb', line 253 def source_info @source_info end |
#source_root ⇒ Toys::SourceInfo? (readonly)
The root source info defining this tool, or nil if there is no source.
136 137 138 |
# File 'core-docs/toys/tool_definition.rb', line 136 def source_root @source_root end |
#subtool_middleware_stack ⇒ Array<Toys::Middleware::Spec> (readonly)
The stack of middleware specs used for subtools.
This array may be modified in place.
238 239 240 |
# File 'core-docs/toys/tool_definition.rb', line 238 def subtool_middleware_stack @subtool_middleware_stack end |
#tool_class ⇒ Class (readonly)
The tool class.
143 144 145 |
# File 'core-docs/toys/tool_definition.rb', line 143 def tool_class @tool_class end |
#usage_error_handler ⇒ Proc, ...
The usage error handler.
This handler is called when at least one usage error is detected during
argument parsing, and is called instead of the run method. It can be
specified as a Proc, or a Symbol indicating a method to call. It
optionally takes an array of ArgParser::UsageError as the sole
argument.
312 313 314 |
# File 'core-docs/toys/tool_definition.rb', line 312 def usage_error_handler @usage_error_handler end |
#used_flags ⇒ Array<String> (readonly)
A list of flags that have been used in the flag definitions.
222 223 224 |
# File 'core-docs/toys/tool_definition.rb', line 222 def used_flags @used_flags end |
Instance Method Details
#add_acceptor(name, acceptor = nil, type_desc: nil, &block) ⇒ self
Add a named acceptor to the tool. This acceptor may be refereneced by name when adding a flag or an arg. See Acceptor.create for detailed information on how to specify an acceptor.
628 629 630 |
# File 'core-docs/toys/tool_definition.rb', line 628 def add_acceptor(name, acceptor = nil, type_desc: nil, &block) # Source available in the toys-core gem end |
#add_completion(name, completion = nil, **options, &block) ⇒ self
Add a named completion proc to this tool. The completion may be referenced by name when adding a flag or an arg. See Completion.create for detailed information on how to specify a completion.
661 662 663 |
# File 'core-docs/toys/tool_definition.rb', line 661 def add_completion(name, completion = nil, **, &block) # Source available in the toys-core gem end |
#add_flag(key, flags = [], accept: nil, default: nil, handler: nil, complete_flags: nil, complete_values: nil, report_collisions: true, group: nil, desc: nil, long_desc: nil, display_name: nil) ⇒ self
Add a flag to the current tool. Each flag must specify a key which
the script may use to obtain the flag value from the context.
You may then provide the flags themselves in OptionParser form.
794 795 796 797 798 799 |
# File 'core-docs/toys/tool_definition.rb', line 794 def add_flag(key, flags = [], accept: nil, default: nil, handler: nil, complete_flags: nil, complete_values: nil, report_collisions: true, group: nil, desc: nil, long_desc: nil, display_name: nil) # Source available in the toys-core gem end |
#add_flag_group(type: :optional, desc: nil, long_desc: nil, name: nil, report_collisions: true, prepend: false) ⇒ self
Add a flag group to the group list.
The type should be one of the following symbols:
-
:optionalAll flags in the group are optional -
:requiredAll flags in the group are required -
:exactly_oneExactly one flag in the group must be provided -
:at_least_oneAt least one flag in the group must be provided -
:at_most_oneAt most one flag in the group must be provided
737 738 739 740 |
# File 'core-docs/toys/tool_definition.rb', line 737 def add_flag_group(type: :optional, desc: nil, long_desc: nil, name: nil, report_collisions: true, prepend: false) # Source available in the toys-core gem end |
#add_initializer(proc, *args, **kwargs) ⇒ self
Add an initializer.
977 978 979 |
# File 'core-docs/toys/tool_definition.rb', line 977 def add_initializer(proc, *args, **kwargs) # Source available in the toys-core gem end |
#add_mixin(name, mixin_module = nil, &block) ⇒ self
Add a named mixin module to this tool. You may provide a mixin module or a block that configures one.
642 643 644 |
# File 'core-docs/toys/tool_definition.rb', line 642 def add_mixin(name, mixin_module = nil, &block) # Source available in the toys-core gem end |
#add_optional_arg(key, default: nil, accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) ⇒ self
Add an optional positional argument to the current tool. You must specify a key which the script may use to obtain the argument value from the context. If an optional argument is not given on the command line, the value is set to the given default.
In general, arguments are parsed in the order they are added to the tool definition. However, all required arguments are always parsed before all optional arguments, even if they are added afterward.
876 877 878 879 |
# File 'core-docs/toys/tool_definition.rb', line 876 def add_optional_arg(key, default: nil, accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) # Source available in the toys-core gem end |
#add_required_arg(key, accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) ⇒ self
Add a required positional argument to the current tool. You must specify a key which the script may use to obtain the argument value from the context.
In general, arguments are parsed in the order they are added to the tool definition. However, all required arguments are always parsed before all optional arguments, even if they are added afterward.
840 841 842 843 |
# File 'core-docs/toys/tool_definition.rb', line 840 def add_required_arg(key, accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) # Source available in the toys-core gem end |
#add_template(name, template_class = nil, &block) ⇒ self
Add a named template class to this tool. You may provide a template class or a block that configures one.
675 676 677 |
# File 'core-docs/toys/tool_definition.rb', line 675 def add_template(name, template_class = nil, &block) # Source available in the toys-core gem end |
#append_long_desc(long_desc) ⇒ self
Append long description strings.
You must pass an array of lines in the long description. See #long_desc for details on how each line may be represented.
609 610 611 |
# File 'core-docs/toys/tool_definition.rb', line 609 def append_long_desc(long_desc) # Source available in the toys-core gem end |
#argument_parsing_disabled? ⇒ true, false
Returns true if this tool has disabled argument parsing.
458 459 460 |
# File 'core-docs/toys/tool_definition.rb', line 458 def argument_parsing_disabled? # Source available in the toys-core gem end |
#context_directory ⇒ String?
Return the effective context directory. If there is a custom context directory, uses that. Otherwise, looks for a custom context directory up the tool ancestor chain. If none is found, uses the default context directory from the source info. It is possible for there to be no context directory at all, in which case, returns nil.
1025 1026 1027 |
# File 'core-docs/toys/tool_definition.rb', line 1025 def context_directory # Source available in the toys-core gem end |
#definition_finished? ⇒ true, false
Returns true if this tool's definition has been finished and is locked.
450 451 452 |
# File 'core-docs/toys/tool_definition.rb', line 450 def definition_finished? # Source available in the toys-core gem end |
#delegate_to(target) ⇒ self
Causes this tool to delegate to another tool.
1035 1036 1037 |
# File 'core-docs/toys/tool_definition.rb', line 1035 def delegate_to(target) # Source available in the toys-core gem end |
#disable_argument_parsing ⇒ self
Disable argument parsing for this tool.
684 685 686 |
# File 'core-docs/toys/tool_definition.rb', line 684 def disable_argument_parsing # Source available in the toys-core gem end |
#disable_flag(*flags) ⇒ self
Mark one or more flags as disabled, preventing their use by any subsequent flag definition. This may be used to prevent middleware from defining a particular flag.
809 810 811 |
# File 'core-docs/toys/tool_definition.rb', line 809 def disable_flag(*flags) # Source available in the toys-core gem end |
#display_name ⇒ String
A displayable name of this tool, generally the full name delimited by spaces.
337 338 339 |
# File 'core-docs/toys/tool_definition.rb', line 337 def display_name # Source available in the toys-core gem end |
#enforce_flags_before_args(state = true) ⇒ self
Enforce that flags must come before args for this tool.
You may disable enforcement by passoing false for the state.
695 696 697 |
# File 'core-docs/toys/tool_definition.rb', line 695 def enforce_flags_before_args(state = true) # Source available in the toys-core gem end |
#exact_flag_match_required? ⇒ true, false
Returns true if this tool requires exact flag matches.
474 475 476 |
# File 'core-docs/toys/tool_definition.rb', line 474 def exact_flag_match_required? # Source available in the toys-core gem end |
#flags_before_args_enforced? ⇒ true, false
Returns true if this tool enforces flags before args.
466 467 468 |
# File 'core-docs/toys/tool_definition.rb', line 466 def flags_before_args_enforced? # Source available in the toys-core gem end |
#handles_interrupts? ⇒ true, false
Returns true if this tool handles interrupts. This is equivalent to
handles_signal?(2).
391 392 393 |
# File 'core-docs/toys/tool_definition.rb', line 391 def handles_interrupts? # Source available in the toys-core gem end |
#handles_signal?(signal) ⇒ true, false
Returns true if this tool handles the given signal.
401 402 403 |
# File 'core-docs/toys/tool_definition.rb', line 401 def handles_signal?(signal) # Source available in the toys-core gem end |
#handles_usage_errors? ⇒ true, false
Returns true if this tool handles usage errors.
409 410 411 |
# File 'core-docs/toys/tool_definition.rb', line 409 def handles_usage_errors? # Source available in the toys-core gem end |
#include_mixin(mod, *args, **kwargs) ⇒ self
Include the given mixin in the tool class.
The mixin must be given as a module. You can use #lookup_mixin to resolve named mixins.
562 563 564 |
# File 'core-docs/toys/tool_definition.rb', line 562 def include_mixin(mod, *args, **kwargs) # Source available in the toys-core gem end |
#includes_arguments? ⇒ true, false
Returns true if at least one flag or positional argument is defined for this tool.
434 435 436 |
# File 'core-docs/toys/tool_definition.rb', line 434 def includes_arguments? # Source available in the toys-core gem end |
#includes_definition? ⇒ true, false
Returns true if this tool has any definition information.
442 443 444 |
# File 'core-docs/toys/tool_definition.rb', line 442 def includes_definition? # Source available in the toys-core gem end |
#includes_description? ⇒ true, false
Returns true if there is a specific description set for this tool.
425 426 427 |
# File 'core-docs/toys/tool_definition.rb', line 425 def includes_description? # Source available in the toys-core gem end |
#includes_modules? ⇒ true, false
Returns true if this tool has at least one included module.
417 418 419 |
# File 'core-docs/toys/tool_definition.rb', line 417 def includes_modules? # Source available in the toys-core gem end |
#inheritable_helper_methods=(val) ⇒ Object
Set whether helper methods defined in this tool are inherited by subtools.
1010 1011 1012 |
# File 'core-docs/toys/tool_definition.rb', line 1010 def inheritable_helper_methods=(val) # Source available in the toys-core gem end |
#inheritable_helper_methods? ⇒ true, false
Returns true if helper methods defined in this class are inherited by subtools.
483 484 485 |
# File 'core-docs/toys/tool_definition.rb', line 483 def inheritable_helper_methods? # Source available in the toys-core gem end |
#interrupt_handler ⇒ Proc, ...
Return the interrupt handler. This is equivalent to signal_handler(2).
365 366 367 |
# File 'core-docs/toys/tool_definition.rb', line 365 def interrupt_handler # Source available in the toys-core gem end |
#interrupt_handler=(handler) ⇒ Object
Set the interrupt handler. This is equivalent to calling
#set_signal_handler for the SIGINT signal.
935 936 937 |
# File 'core-docs/toys/tool_definition.rb', line 935 def interrupt_handler=(handler) # Source available in the toys-core gem end |
#lock_source(source) ⇒ self
Sets the path to the file that defines this tool. A tool may be defined from at most one path. If a different path is already set, it is left unchanged.
574 575 576 |
# File 'core-docs/toys/tool_definition.rb', line 574 def lock_source(source) # Source available in the toys-core gem end |
#lookup_acceptor(name) ⇒ Toys::Acceptor::Base?
Get the named acceptor from this tool or its ancestors.
516 517 518 |
# File 'core-docs/toys/tool_definition.rb', line 516 def lookup_acceptor(name) # Source available in the toys-core gem end |
#lookup_completion(name) ⇒ Toys::Completion::Base, ...
Get the named completion from this tool or its ancestors.
549 550 551 |
# File 'core-docs/toys/tool_definition.rb', line 549 def lookup_completion(name) # Source available in the toys-core gem end |
#lookup_mixin(name) ⇒ Module?
Get the named mixin from this tool or its ancestors.
538 539 540 |
# File 'core-docs/toys/tool_definition.rb', line 538 def lookup_mixin(name) # Source available in the toys-core gem end |
#lookup_template(name) ⇒ Class?
Get the named template from this tool or its ancestors.
527 528 529 |
# File 'core-docs/toys/tool_definition.rb', line 527 def lookup_template(name) # Source available in the toys-core gem end |
#positional_args ⇒ Array<Toys::PositionalArg>
All arg definitions in order: required, optional, remaining.
492 493 494 |
# File 'core-docs/toys/tool_definition.rb', line 492 def positional_args # Source available in the toys-core gem end |
#require_exact_flag_match(state = true) ⇒ self
Require that flags must match exactly. (If false, flags can match an unambiguous substring.)
706 707 708 |
# File 'core-docs/toys/tool_definition.rb', line 706 def require_exact_flag_match(state = true) # Source available in the toys-core gem end |
#resolve_flag(str) ⇒ Toys::Flag::Resolution
Resolve the given flag given the flag string. Returns an object that describes the resolution result, including whether the resolution matched a unique flag, the specific flag syntax that was matched, and additional information.
505 506 507 |
# File 'core-docs/toys/tool_definition.rb', line 505 def resolve_flag(str) # Source available in the toys-core gem end |
#root? ⇒ true, false
Returns true if this tool is a root tool.
373 374 375 |
# File 'core-docs/toys/tool_definition.rb', line 373 def root? # Source available in the toys-core gem end |
#runnable? ⇒ true, false
Returns true if this tool is marked as runnable.
381 382 383 |
# File 'core-docs/toys/tool_definition.rb', line 381 def runnable? # Source available in the toys-core gem end |
#set_remaining_args(key, default: [], accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) ⇒ self
Specify what should be done with unmatched positional arguments. You must specify a key which the script may use to obtain the remaining args from the context.
907 908 909 910 |
# File 'core-docs/toys/tool_definition.rb', line 907 def set_remaining_args(key, default: [], accept: nil, complete: nil, display_name: nil, desc: nil, long_desc: nil) # Source available in the toys-core gem end |
#set_signal_handler(signal, handler) ⇒ Object
Set the handler for the given signal.
This handler is called when the given signal is received, immediately
taking over the execution as if it were the new run method. The signal
handler can be specified as a Proc, or a Symbol indicating a method to
call. It optionally takes the SignalException as the sole argument.
950 951 952 |
# File 'core-docs/toys/tool_definition.rb', line 950 def set_signal_handler(signal, handler) # Source available in the toys-core gem end |
#signal_handler(signal) ⇒ Proc, ...
Return the signal handler for the given signal.
This handler is called when the given signal is received, immediately
taking over the execution as if it were the new run handler. The signal
handler can be specified as a Proc, or a Symbol indicating a method to
call. It optionally takes the SignalException as the sole argument.
354 355 356 |
# File 'core-docs/toys/tool_definition.rb', line 354 def signal_handler(signal) # Source available in the toys-core gem end |
#simple_name ⇒ String
The local name of this tool, i.e. the last element of the full name.
327 328 329 |
# File 'core-docs/toys/tool_definition.rb', line 327 def simple_name # Source available in the toys-core gem end |