Class: Toys::Utils::GitCache
- Inherits:
-
Object
- Object
- Toys::Utils::GitCache
- Defined in:
- core-docs/toys/utils/git_cache.rb,
core-docs/toys/utils/git_cache.rb,
core-docs/toys/utils/git_cache.rb,
core-docs/toys/utils/git_cache.rb,
core-docs/toys/utils/git_cache.rb
Overview
Defined in the toys-core gem
This object provides cached access to remote git data. Given a remote repository, a path, and a commit, it makes the files available in the local filesystem. Access is cached, so repeated requests for the same commit and path in the same repo do not hit the remote repository again.
Defined Under Namespace
Classes: Error, RefInfo, RepoInfo, SourceInfo
Constant Summary collapse
- VERSION =
Version of the git_cache gem
"0.1.1"
Instance Attribute Summary collapse
-
#cache_dir ⇒ String
readonly
The cache directory.
Instance Method Summary collapse
-
#get(remote, path: nil, commit: nil, into: nil, update: false, timestamp: nil) ⇒ String
(also: #find)
Get the given git-based files from the git cache, loading from the remote repo if necessary.
-
#initialize(cache_dir: nil) ⇒ GitCache
constructor
Access a git cache.
-
#remotes ⇒ Array<String>
Returns an array of the known remote names.
-
#remove_refs(remote, refs: nil) ⇒ Array<RefInfo>?
Remove records of the given refs (i.e. branches, tags, or
HEAD) from the given repository's cache. -
#remove_repos(remotes) ⇒ Array<String>
Removes caches for the given repos, or all repos if specified.
-
#remove_sources(remote, commits: nil) ⇒ Array<SourceInfo>?
Removes shared sources for the given cache.
-
#repo_info(remote) ⇒ RepoInfo?
Returns a RepoInfo describing the cache for the given remote, or
nilif the given remote has never been cached.
Constructor Details
#initialize(cache_dir: nil) ⇒ GitCache
Access a git cache.
21 22 23 |
# File 'core-docs/toys/utils/git_cache.rb', line 21 def initialize(cache_dir: nil) # Source available in the toys-core gem end |
Instance Attribute Details
#cache_dir ⇒ String (readonly)
The cache directory.
30 31 32 |
# File 'core-docs/toys/utils/git_cache.rb', line 30 def cache_dir @cache_dir end |
Instance Method Details
#get(remote, path: nil, commit: nil, into: nil, update: false, timestamp: nil) ⇒ String Also known as: find
Get the given git-based files from the git cache, loading from the remote repo if necessary.
The resulting files are either copied into a directory you provide in
the :into parameter, or populated into a shared source directory if
you omit the :into parameter. In the latter case, it is important
that you do not modify the returned files or directories, nor add or
remove any files from the directories returned, to avoid confusing
callers that could be given the same directory. If you need to make any
modifications to the returned files, use :into to provide your own
private directory.
68 69 70 |
# File 'core-docs/toys/utils/git_cache.rb', line 68 def get(remote, path: nil, commit: nil, into: nil, update: false, timestamp: nil) # Source available in the toys-core gem end |
#remotes ⇒ Array<String>
Returns an array of the known remote names.
78 79 80 |
# File 'core-docs/toys/utils/git_cache.rb', line 78 def remotes # Source available in the toys-core gem end |
#remove_refs(remote, refs: nil) ⇒ Array<RefInfo>?
Remove records of the given refs (i.e. branches, tags, or HEAD) from
the given repository's cache. The next time those refs are requested,
they will be pulled from the remote repo.
If you provide the refs: argument, only those refs are removed.
Otherwise, all refs are removed.
125 126 127 |
# File 'core-docs/toys/utils/git_cache.rb', line 125 def remove_refs(remote, refs: nil) # Source available in the toys-core gem end |
#remove_repos(remotes) ⇒ Array<String>
Removes caches for the given repos, or all repos if specified.
Removes all cache information for the specified repositories, including local clones and shared source directories. The next time these repositories are requested, they will be reloaded from the remote repository from scratch.
Be careful not to remove repos that are currently in use by other Toys::Utils::GitCache clients.
108 109 110 |
# File 'core-docs/toys/utils/git_cache.rb', line 108 def remove_repos(remotes) # Source available in the toys-core gem end |
#remove_sources(remote, commits: nil) ⇒ Array<SourceInfo>?
Removes shared sources for the given cache. The next time a client requests them, the removed sources will be recopied from the repo.
If you provide the commits: argument, only sources associated with
those commits are removed. Otherwise, all sources are removed.
Be careful not to remove sources that are currently in use by other Toys::Utils::GitCache clients.
145 146 147 |
# File 'core-docs/toys/utils/git_cache.rb', line 145 def remove_sources(remote, commits: nil) # Source available in the toys-core gem end |