Exception: Toys::Utils::GitCache::Error
- Inherits:
-
StandardError
- Object
- StandardError
- Toys::Utils::GitCache::Error
- Defined in:
- core-docs/toys/utils/git_cache.rb
Overview
Defined in the toys-core gem
Toys::Utils::GitCache encountered a failure
Instance Attribute Summary collapse
-
#exec_result ⇒ ::Toys::Utils::Exec::Result
readonly
The result of a git command execution, or
nilif this error was not due to a git command error.
Instance Method Summary collapse
-
#initialize(message, result) ⇒ Error
constructor
Create a Toys::Utils::GitCache::Error.
Constructor Details
#initialize(message, result) ⇒ Error
Create a Toys::Utils::GitCache::Error.
165 166 167 |
# File 'core-docs/toys/utils/git_cache.rb', line 165 def initialize(, result) # Source available in the toys-core gem end |
Instance Attribute Details
#exec_result ⇒ ::Toys::Utils::Exec::Result (readonly)
Returns The result of a git command
execution, or nil if this error was not due to a git command
error.
174 175 176 |
# File 'core-docs/toys/utils/git_cache.rb', line 174 def exec_result @exec_result end |